import { getPartnerEngineConfig, getSelectedChoices, isFeatureEnabled, removeActiveAnswerId, searchChoices, searchChoicesWithNudges, } from '@boldpenguin/sdk-redux';
import { Component, Element, h, Listen, Prop, State, Watch } from '@stencil/core';
import { store } from '@stencil/redux';
import isEmpty from 'lodash/isEmpty';
import { canGetStore } from '../../utils/store';
export class BpSdkBusinessClassificationSelectorContainer {
  constructor() {
    /**
     * Question code
     */
    this.code = '';
    /**
     * Placeholder to display
     */
    this.placeholder = '';
    /**
     * Is required value
     */
    this.required = false;
    /**
     * Is touched
     */
    this.touched = false;
    /**
     * Is pristine
     */
    this.pristine = true;
    /**
     * Is answer in complete state
     */
    this.isCompleted = false;
    /**
     * When true, the field will be readonly. It will display only the label and value as plain text.
     */
    this.isReadOnly = false;
    /**
     * Choices from answer
     */
    this.choices = [];
    /**
     * Choices injected from redux
     */
    this.remoteChoices = [];
    /**
     * Is refiltered enabled injected from redux
     */
    this.isRefilteringEnabled = false;
    this.choiceMap = {};
    this._selectedChoices = [];
    this._searchChoices = [];
    this._currentSearchValue = '';
    this.useExternal = false;
    this.showChoices = false;
    this._refilterAnswers = {};
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { searchChoices, removeActiveAnswerId, searchChoicesWithNudges });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        showNaicsCode: state.viewState.features.list.includes('bcs_show_naics_code'),
        showConfidence: state.viewState.features.list.includes('bcs_show_naics_level'),
        remoteChoices: getSelectedChoices(state, this.questionId),
        config: getPartnerEngineConfig(state),
        isRefilteringEnabled: isFeatureEnabled(state, 'bcs_refilter'),
      };
    };
  }
  resetState() {
    this.showChoices = false;
    this._currentSearchValue = '';
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-container');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-container').then(() => {
      this.useExternal = true;
    });
    this.onQuestionIdChange();
    this.onChoicesChange(this.choices || []);
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onQuestionIdChange() {
    this.handleSubscriptions();
  }
  doSearchChoices() {
    if (this.useExternal) {
      return;
    }
    const params = {
      config: this.config,
      filter: this._currentSearchValue,
      questionId: this.questionId,
      timestamp: Date.now(),
      refilter: null,
    };
    if (this.isRefilteringEnabled) {
      if (!isEmpty(this._refilterAnswers)) {
        params.refilter = JSON.stringify(this._refilterAnswers);
      }
      this.searchChoicesWithNudges(params);
    }
    else {
      this.searchChoices(params);
    }
  }
  onFilterUpdate({ detail }) {
    if (this.useExternal) {
      return;
    }
    this.showChoices = true;
    this._currentSearchValue = detail.value;
    this._refilterAnswers = {};
    this.doSearchChoices();
  }
  onRefilterAnswer({ detail }) {
    // Add nudge answer to local state, it gets used in doSearchChoices
    this._refilterAnswers[detail.key] = detail.answer ? 'Y' : 'N';
    this.doSearchChoices();
  }
  onValueUpdate() {
    if (this.useExternal) {
      return;
    }
    this.showChoices = false;
    this.removeActiveAnswerId();
  }
  onChoicesChange(choices) {
    this.choiceMap = choices.reduce((acc, choice) => (Object.assign(Object.assign({}, acc), { [choice.id]: [choice] })), {});
  }
  onChoicesUpdate(choices) {
    this.updateComposedChoices(choices, this.choiceMap);
  }
  onChoiceMapUpdate(choiceMap) {
    this.updateComposedChoices(this.remoteChoices, choiceMap);
  }
  updateComposedChoices(searchChoices, choiceMap) {
    this._selectedChoices = choiceMap && choiceMap[this.choiceId] ? choiceMap[this.choiceId] : [];
    this._searchChoices = searchChoices;
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-container", { answerId: this.answerId, choiceId: this.choiceId, choices: this.choices, code: this.code, config: this.config, errors: this.errors, errorText: this.errorText, fieldType: this.fieldType, helpText: this.helpText, answeredBySource: this.answeredBySource, isCompleted: this.isCompleted, isReadOnly: this.isReadOnly, labelId: this.labelId, label: this.label, labelledBy: this.labelledBy, placeholder: this.placeholder, pristine: this.pristine, questionId: this.questionId, remoteChoices: this.remoteChoices, required: this.required, touched: this.touched, showConfidence: this.showConfidence, showNaicsCode: this.showNaicsCode, selectedChoices: this._selectedChoices, isRefilteringEnabled: this.isRefilteringEnabled }));
  }
  renderInternal() {
    return [
      h("bp-sdk-business-classification-selector", { answerId: this.answerId, choiceId: this.choiceId, choices: this._searchChoices, code: this.code, errors: this.errors, errorText: this.errorText, fieldType: this.fieldType, helpText: this.helpText, answeredBySource: this.answeredBySource, isCompleted: this.isCompleted, isReadOnly: this.isReadOnly, label: this.label, labelId: this.labelId, labelledBy: this.labelledBy, placeholder: this.placeholder, pristine: this.pristine, questionId: this.questionId, required: this.required, touched: this.touched, showChoices: this.showChoices, showConfidence: this.showConfidence, showNaicsCode: this.showNaicsCode, selectedChoices: this._selectedChoices, isRefilteringEnabled: this.isRefilteringEnabled }),
    ];
  }
  static get is() { return "bp-sdk-business-classification-selector-container"; }
  static get originalStyleUrls() { return {
    "$": ["./bp-sdk-business-classification-selector-container.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-business-classification-selector-container.css"]
  }; }
  static get properties() { return {
    "answerId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Answer id"
      },
      "attribute": "answer-id",
      "reflect": false
    },
    "questionId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question id"
      },
      "attribute": "question_id",
      "reflect": false
    },
    "code": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question code"
      },
      "attribute": "code",
      "reflect": false,
      "defaultValue": "''"
    },
    "placeholder": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Placeholder to display"
      },
      "attribute": "placeholder",
      "reflect": false,
      "defaultValue": "''"
    },
    "required": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is required value"
      },
      "attribute": "required",
      "reflect": false,
      "defaultValue": "false"
    },
    "errors": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "string[] | undefined",
        "resolved": "string[]",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Error messages"
      }
    },
    "errorText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | undefined",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Error text"
      },
      "attribute": "error_text",
      "reflect": false
    },
    "labelId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Aria label id's that describes input for screen readers"
      },
      "attribute": "label-id",
      "reflect": false
    },
    "choiceId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "*\nSelected choice"
      },
      "attribute": "choice_id",
      "reflect": false
    },
    "touched": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is touched"
      },
      "attribute": "touched",
      "reflect": false,
      "defaultValue": "false"
    },
    "pristine": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is pristine"
      },
      "attribute": "pristine",
      "reflect": false,
      "defaultValue": "true"
    },
    "isCompleted": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is answer in complete state"
      },
      "attribute": "is_completed",
      "reflect": false,
      "defaultValue": "false"
    },
    "isReadOnly": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "When true, the field will be readonly. It will display only the label and value as plain text."
      },
      "attribute": "is-read-only",
      "reflect": false,
      "defaultValue": "false"
    },
    "fieldType": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Field type"
      },
      "attribute": "field_type",
      "reflect": false
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label to use"
      },
      "attribute": "label",
      "reflect": false
    },
    "labelledBy": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Labels that describe group"
      },
      "attribute": "labelled-by",
      "reflect": false
    },
    "choices": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IChoice[]",
        "resolved": "IChoice[]",
        "references": {
          "IChoice": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Choices from answer"
      },
      "defaultValue": "[]"
    },
    "remoteChoices": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IChoice[]",
        "resolved": "IChoice[]",
        "references": {
          "IChoice": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Choices injected from redux"
      },
      "defaultValue": "[]"
    },
    "showNaicsCode": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Show naics code preference injected from redux"
      },
      "attribute": "show-naics-code",
      "reflect": false
    },
    "showConfidence": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Show confidence score preference injected from redux"
      },
      "attribute": "show-confidence",
      "reflect": false
    },
    "config": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IPartnerEngineConfig",
        "resolved": "IPartnerEngineConfig",
        "references": {
          "IPartnerEngineConfig": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "config injected from redux"
      }
    },
    "isRefilteringEnabled": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is refiltered enabled injected from redux"
      },
      "attribute": "is-refiltering-enabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "helpText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Help text"
      },
      "attribute": "help-text",
      "reflect": false
    },
    "answeredBySource": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | undefined",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifically how the question was answered (ie. \"ACORD 126\")"
      },
      "attribute": "answered-by-source",
      "reflect": false
    }
  }; }
  static get states() { return {
    "choiceMap": {},
    "_selectedChoices": {},
    "_searchChoices": {},
    "_currentSearchValue": {},
    "useExternal": {},
    "showChoices": {},
    "_refilterAnswers": {}
  }; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "questionId",
      "methodName": "onQuestionIdChange"
    }, {
      "propName": "choices",
      "methodName": "onChoicesChange"
    }, {
      "propName": "remoteChoices",
      "methodName": "onChoicesUpdate"
    }, {
      "propName": "choiceMap",
      "methodName": "onChoiceMapUpdate"
    }]; }
  static get listeners() { return [{
      "name": "filterUpdate",
      "method": "onFilterUpdate",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "nudgeAnswer",
      "method": "onRefilterAnswer",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "valueUpdate",
      "method": "onValueUpdate",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}
