import { Component, Prop, h, State, Element } from '@stencil/core';
import { store } from '@stencil/redux';
import { canGetStore } from '../../utils/store';
export class BpSdkDriverQuestionSetContainer {
  constructor() {
    /**
     * Mapped question groups
     */
    this.questionGroupsWithAnswersAsKey = new Map();
    /**
     * Driver count limit
     */
    this.driverLimit = 20;
    this.useExternal = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        errors: state.application.errors,
        driverLimit: state.config.options.driverLimit,
      };
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-question-set-container');
    customElements.whenDefined('bp-sdk-external-driver-question-set-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-driver-question-set-container", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, driverLimit: this.driverLimit, errors: this.errors, locked: this.locked, questionSet: this.questionSet, saveHandler: this.saveHandler, questionGroupsWithAnswersAsKey: this.questionGroupsWithAnswersAsKey }));
  }
  renderInternal() {
    return (h("bp-sdk-driver-question-set", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, errors: this.errors, locked: this.locked, maxDrivers: this.driverLimit, questionSet: this.questionSet, saveHandler: this.saveHandler, questionGroupsWithAnswersAsKey: this.questionGroupsWithAnswersAsKey }));
  }
  static get is() { return "bp-sdk-driver-question-set-container"; }
  static get originalStyleUrls() { return {
    "$": ["./bp-sdk-driver-question-set-container.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-driver-question-set-container.css"]
  }; }
  static get properties() { return {
    "errors": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IErrorState",
        "resolved": "IErrorState",
        "references": {
          "IErrorState": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Error states"
      }
    },
    "questionSet": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IApplicationFormQuestionSet",
        "resolved": "IApplicationFormQuestionSet",
        "references": {
          "IApplicationFormQuestionSet": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question Set"
      }
    },
    "locked": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is application locked"
      },
      "attribute": "locked",
      "reflect": false
    },
    "canSave": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Can save"
      },
      "attribute": "can-save",
      "reflect": false
    },
    "areResourcesReady": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Flag used to disable button if resources for question set are not ready"
      },
      "attribute": "are-resources-ready",
      "reflect": false
    },
    "saveHandler": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(questionSet: IApplicationFormQuestionSet) => void",
        "resolved": "(questionSet: IApplicationFormQuestionSet) => void",
        "references": {
          "IApplicationFormQuestionSet": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Save Question set function"
      }
    },
    "questionGroupsWithAnswersAsKey": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Map<string, IMappedQuestionGroupAnswers>",
        "resolved": "Map<string, IMappedQuestionGroupAnswers>",
        "references": {
          "Map": {
            "location": "global"
          },
          "IMappedQuestionGroupAnswers": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Mapped question groups"
      },
      "defaultValue": "new Map()"
    },
    "driverLimit": {
      "type": "number",
      "mutable": true,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Driver count limit"
      },
      "attribute": "driver-limit",
      "reflect": false,
      "defaultValue": "20"
    }
  }; }
  static get states() { return {
    "useExternal": {}
  }; }
  static get elementRef() { return "el"; }
}
