import { Component, Prop, h, State, Watch } from '@stencil/core';
import { store } from '@stencil/redux';
import { store as sdkStore, setWebSocketConfig } from '@boldpenguin/sdk-redux';
import { canGetStore } from '../../utils/store';
export class BpSdkRoot {
  constructor() {
    /**
     * Disable web socket
     */
    this.disableWebSocket = false;
    /**
     * Disable lifecycle events, false by default
     */
    this.enableLifecycleEvents = false;
    /**
     * Disable toolbar
     */
    this.disableToolbar = false;
    this.storeLoaded = false;
  }
  onDisabledWebSocket(disableWebSocket) {
    sdkStore.dispatch(setWebSocketConfig({ enableWebsocket: !disableWebSocket }));
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    store.setStore(sdkStore);
    this.storeLoaded = true;
    this.onDisabledWebSocket(this.disableWebSocket);
  }
  render() {
    if (!canGetStore()) {
      return null;
    }
    return (this.storeLoaded && (h("bp-sdk-setup-container", null,
      [!!this.enableLifecycleEvents && h("bp-sdk-custom-event-container", null), !this.disableToolbar && h("bp-sdk-interview-toolbar", null)],
      h("slot", null))));
  }
  static get is() { return "bp-sdk-root"; }
  static get properties() { return {
    "completedAt": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "Date",
        "resolved": "Date",
        "references": {
          "Date": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    },
    "disableWebSocket": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Disable web socket"
      },
      "attribute": "disable-web-socket",
      "reflect": false,
      "defaultValue": "false"
    },
    "enableLifecycleEvents": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Disable lifecycle events, false by default"
      },
      "attribute": "enable-lifecycle-events",
      "reflect": false,
      "defaultValue": "false"
    },
    "disableToolbar": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Disable toolbar"
      },
      "attribute": "disable-toolbar",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "storeLoaded": {}
  }; }
  static get watchers() { return [{
      "propName": "disableWebSocket",
      "methodName": "onDisabledWebSocket"
    }]; }
}
